@@ -10,9 +10,10 @@ from ..util_core.selector import GroupSelector
 from ..util_core.utils import get_ip, gen_cert, readchar, is_ipv4
 
 class TLSModifier:
-    def __init__(self, group_tag, group_index, domain='', alpn=None):
+    def __init__(self, group_tag, group_index, domain='', alpn=None, xtls=False):
         self.domain = domain
         self.alpn = alpn
+        self.xtls = xtls
         self.writer = GroupWriter(group_tag, group_index)
     
     @restart(True)
@@ -44,7 +45,7 @@ class TLSModifier:
             crt_file = "/root/.acme.sh/" + input_domain +"_ecc"+ "/fullchain.cer"
             key_file = "/root/.acme.sh/" + input_domain +"_ecc"+ "/"+ input_domain +".key"
 
-            self.writer.write_tls(True, crt_file=crt_file, key_file=key_file, domain=input_domain, alpn=self.alpn)
+            self.writer.write_tls(True, crt_file=crt_file, key_file=key_file, domain=input_domain, alpn=self.alpn, xtls=self.xtls)
 
         elif choice == "2":
             crt_file = input(_("please input certificate cert file path: "))
@@ -57,7 +58,7 @@ class TLSModifier:
                 if not input_domain:
                     print(_("domain is null!"))
                     return
-            self.writer.write_tls(True, crt_file=crt_file, key_file=key_file, domain=input_domain, alpn=self.alpn)
+            self.writer.write_tls(True, crt_file=crt_file, key_file=key_file, domain=input_domain, alpn=self.alpn, xtls=self.xtls)
         else:
             print(_("input error!"))
             return
